pub struct OrderStateSnapshot {
pub quantity: Quantity,
pub price: Option<Price>,
pub trigger_price: Option<Price>,
}Expand description
Snapshot of an order’s price, quantity, and trigger price at last dispatch. Used to detect modifications when Bybit sends back an order with the same status but changed fields.
Fields
quantity: Quantityprice: Option<Price>trigger_price: Option<Price>Trait Implementations
Sourceimpl Clone for OrderStateSnapshot
impl Clone for OrderStateSnapshot
Sourcefn clone(&self) -> OrderStateSnapshot
fn clone(&self) -> OrderStateSnapshot
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreAuto Trait Implementations
impl Freeze for OrderStateSnapshot
impl RefUnwindSafe for OrderStateSnapshot
impl Send for OrderStateSnapshot
impl Sync for OrderStateSnapshot
impl Unpin for OrderStateSnapshot
impl UnsafeUnpin for OrderStateSnapshot
impl UnwindSafe for OrderStateSnapshot