pub type PendingRequestData = (Vec<ClientOrderId>, Vec<Option<VenueOrderId>>, PendingOperation);Expand description
Shared state for cross-stream event deduplication between the private and trade WebSocket dispatch loops.
pub type PendingRequestData = (Vec<ClientOrderId>, Vec<Option<VenueOrderId>>, PendingOperation);Shared state for cross-stream event deduplication between the private and trade WebSocket dispatch loops.